@@ -1,6 +1,8 @@
 import time
 from http.client import HTTPException
 
+from evernote_backup.config import NETWORK_ERROR_RETRY_COUNT
+
 
 class EvernoteAuthError(Exception):
     """Evernote authentication error"""
@@ -8,7 +10,7 @@ class EvernoteAuthError(Exception):
 
 def network_retry(fun):
     def wrapper(*args, **kwargs):
-        retry_count = 50
+        retry_count = NETWORK_ERROR_RETRY_COUNT
 
         for i in range(retry_count):
             try:
